@@ -1626,7 +1626,7 @@ _gnutls_x509_get_signature (ASN1_TYPE src, const char *src_name,
                             gnutls_datum_t * signature)
 {
   int result, len;
-  unsigned int bits;
+  int bits;
 
   signature->data = NULL;
   signature->size = 0;
@@ -1644,7 +1644,7 @@ _gnutls_x509_get_signature (ASN1_TYPE src, const char *src_name,
     }
 
   bits = len;
-  if (bits % 8 != 0)
+  if (bits % 8 != 0 || bits < 8)
     {
       gnutls_assert ();
       result = GNUTLS_E_CERTIFICATE_ERROR;
